# arpes.utilities.region module

**arpes.utilities.region.normalize\_region(region: Union\[str, dict\])**

**class arpes.utilities.region.DesignatedRegions**

> Bases: `enum.Enum`
> 
> An enumeration.
> 
> `ABOVE_EF = 11`
> 
> `ABOVE_EFFECTIVE_EF = 21`
> 
> `BELOW_EF = 10`
> 
> `BELOW_EFFECTIVE_EF = 20`
> 
> `EFFECTIVE_EF_NARROW = 22`
> 
> `EF_NARROW = 12`
> 
> `MESO_EF = 13`
> 
> `MESO_EFFECTIVE_EF = 23`
> 
> `NARROW_ANGLE = 0`
> 
> `TRIM_EMPTY = 2`
> 
> `WIDE_ANGLE = 1`
